@@ -13,7 +13,7 @@ from optparse import OptionParser
 
 from dbtexmf.core.confparser import DbtexConfig, texinputs_parse, texstyle_parse
 from dbtexmf.xslt import xslt
-from dbtexmf.core.logger import logger
+import dbtexmf.core.logger as logger
 from dbtexmf.core.error import signal_error, failed_exit, dump_stack
 
 
@@ -199,7 +199,7 @@ class DbTex:
 
         f.write('</xsl:stylesheet>\n')
         f.close()
-        self.xslbuild = wrapper
+        self.xslbuild = os.path.realpath(wrapper)
 
     def make_xml(self):
         self.log.info("Build the XML file...")
@@ -265,12 +265,12 @@ class DbTex:
         self.xsltproc.use_catalogs = 0
         self.xsltproc.run(xslset, self.input, doclist, opts=self.xslopts)
 
-        # If <doclist> is missing, there's no set, or only one book from
-        # the set is compiled
-        if not(os.path.isfile(doclist)):
-            self._single_setup()
-        else:
+        # If <doclist> is missing or is empty, there's no set, or only one
+        # book from the set is compiled
+        if os.path.isfile(doclist) and os.path.getsize(doclist) > 0:
             self._multiple_setup(doclist)
+        else:
+            self._single_setup()
 
     def make_rawtex(self):
         if len(self.documents) == 1:
@@ -422,6 +422,8 @@ class DbTexCommand:
                                "which %s actually works" % prog)
         parser.add_option("-D", "--dump", action="store_true",
                           help="Dump error stack (debug purpose)")
+        parser.add_option("-e", "--indexstyle",
+                          help="Index Style file to pass to makeindex")
         parser.add_option("-f", "--fig-format",
                           help="Input figure format, used when not deduced "
                                "from figure extension")
@@ -454,6 +456,8 @@ class DbTexCommand:
         parser.add_option("-P", "--param", dest="xslparams",
                           action="append", metavar="PARAM=VALUE",
                           help="Set an XSL parameter value from command line")
+        parser.add_option("-q", "--quiet", action="store_true",
+                          help="Less verbose, showing only error messages")
         parser.add_option("-r", "--texpost", metavar="SCRIPT",
                           help="Script called at the very end of the tex "
                                "compilation. Its role is to modify the tex file "
@@ -542,6 +546,9 @@ class DbTexCommand:
             run.xslparams.append(xslparam)
             if texpath: run.texinputs.append(texpath)
 
+        if options.indexstyle:
+            run.runtex.index_style = os.path.abspath(options.indexstyle)
+
         if options.texinputs:
             for texinputs in options.texinputs:
                 run.texinputs += texinputs_parse(texinputs)
@@ -576,7 +583,10 @@ class DbTexCommand:
 
         if options.verbose:
             run.verbose = options.verbose
-    
+
+        if options.quiet:
+            run.verbose = logger.QUIET
+
         if options.tmpdir:
             if not(os.path.exists(options.tmpdir)):
                 try:
@@ -647,7 +657,7 @@ class DbTexCommand:
         self.run_setup(options)
 
         # Verbose mode
-        run.log = logger(self.prog, run.verbose)
+        run.log = logger.logger(self.prog, run.verbose)
 
         # Data from standard input?
         if args[0] == "-":
